Crate enum_tree_derive

Crate enum_tree_derive 

Derive Macros

DeepVariants
Create a const array with all possible values of an enum. Target must be an enum, and each variant of the target must be of nested unit type. A variant is of nested unit type if it is either:
EnumFrom
Derive From implementations for an enum from variants.
IntoAncestors
Derive From<Self> for every enum mentioned in an #[ancestors(Parent::Variant)] attribute.