#[derive(DeepVariants)]
{
// Attributes available to this derive:
#[ancestors]
#[enum_tree]
}
Create a const array with all possible values of an enum.
Target must be an enum, and each variant of the target must be of nested unit type.
A variant is of nested unit type if it is either:
a) a unit variant, or b) an singleton tuple variant, whose inner type is compatible.
Variants annotated with #[enum_tree(skip)] are excluded.